@@ -1,10 +1,10 @@
-/* $Id: xm_api.c,v 1.29.2.1 2001/11/06 16:00:58 brianp Exp $ */
+/* $Id: xm_api.c,v 1.29.2.6 2002/03/16 00:50:13 brianp Exp $ */
 
 /*
  * Mesa 3-D graphics library
- * Version:  3.5
+ * Version:  4.0.2
  *
- * Copyright (C) 1999-2000  Brian Paul   All Rights Reserved.
+ * Copyright (C) 1999-2002  Brian Paul   All Rights Reserved.
  *
  * Permission is hereby granted, free of charge, to any person obtaining a
  * copy of this software and associated documentation files (the "Software"),
@@ -23,7 +23,7 @@
  * AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
  * CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
  */
-
+/* $XFree86: xc/extras/Mesa/src/X/xm_api.c,v 1.2 2002/02/26 23:37:31 tsi Exp $ */
 
 /*
  * This file contains the implementations of all the XMesa* functions.
@@ -168,6 +168,8 @@ static short hpcr_rgbTbl[3][256] = {
  */
 static void error( const char *msg )
 {
+   (void)DitherValues;		/* Muffle compiler */
+
    if (getenv("MESA_DEBUG"))
       fprintf( stderr, "X/Mesa error: %s\n", msg );
 }
@@ -1306,23 +1308,31 @@ static GLboolean initialize_visual_and_buffer( int client,
 #endif
       XMesaSetFunction( v->display, b->gc, GXcopy );
 
+      /* cleargc - for glClear() */
+#ifdef XFree86Server
+      b->cleargc = CreateScratchGC(v->display, window->depth);
+#else
+      b->cleargc = XCreateGC( v->display, window, 0, NULL );
+#endif
+      XMesaSetFunction( v->display, b->cleargc, GXcopy );
+
       /*
        * Don't generate Graphics Expose/NoExpose events in swapbuffers().
        * Patch contributed by Michael Pichler May 15, 1995.
        */
 #ifdef XFree86Server
-      b->cleargc = CreateScratchGC(v->display, window->depth);
+      b->swapgc = CreateScratchGC(v->display, window->depth);
       {
 	  CARD32 v[1];
 	  v[0] = FALSE;
-	  dixChangeGC(NullClient, b->cleargc, GCGraphicsExposures, v, NULL);
+	  dixChangeGC(NullClient, b->swapgc, GCGraphicsExposures, v, NULL);
       }
 #else
       gcvalues.graphics_exposures = False;
-      b->cleargc = XCreateGC( v->display, window,
+      b->swapgc = XCreateGC( v->display, window,
                               GCGraphicsExposures, &gcvalues);
 #endif
-      XMesaSetFunction( v->display, b->cleargc, GXcopy );
+      XMesaSetFunction( v->display, b->swapgc, GXcopy );
       /*
        * Set fill style and tile pixmap once for all for HPCR stuff
        * (instead of doing it each time in clear_color_HPCR_pixmap())
@@ -1690,35 +1700,6 @@ void XMesaDestroyContext( XMesaContext c )
       _mesa_destroy_context( c->gl_ctx );
    }
 
-   /*
-    * XXX This code should really go away because the ancilliary data
-    * associated with a window/pixmap should not go away just because
-    * a context is destroyed.
-    */
-#if 0
-   /* Destroy any buffers which are using this context.  If we don't
-    * we may have dangling references.  Hmm, maybe we should just
-    * set the buffer's context pointer to NULL instead of deleting it?
-    * Let's see if we get any bug reports...
-    * This contributed by Doug Rabson <dfr@calcaphon.com>
-    */
-   {
-      XMesaBuffer b, next;
-      for (b = XMesaBufferList; b; b = next) {
-         next = b->Next;
-         if (!b->pixmap_flag) {
-#ifndef XFree86Server
-            XSync(b->display, False);
-#endif
-            if (b->xm_context == c) {
-               /* found a context created for this context */
-               XMesaDestroyBuffer( b );
-            }
-         }
-      }
-   }
-#endif
-
    FREE( c );
 }
 
@@ -1769,8 +1750,6 @@ XMesaBuffer XMesaCreateWindowBuffer2( XMesaVisual v, XMesaWindow w,
       return NULL;
    }
 
-   b->xm_context = NULL; /* Associate no context with this buffer */
-
    b->xm_visual = v;
    b->pixmap_flag = GL_FALSE;
    b->display = v->display;
@@ -1917,8 +1896,6 @@ XMesaBuffer XMesaCreatePixmapBuffer( XMesaVisual v,
 
    assert(v);
 
-   b->xm_context = NULL; /* Associate no context with this buffer */
-
    b->xm_visual = v;
    b->pixmap_flag = GL_TRUE;
    b->display = v->display;
@@ -1967,8 +1944,6 @@ XMesaBuffer XMesaCreatePBuffer( XMesaVisual v, XMesaColormap cmap,
       return NULL;
    }
 
-   b->xm_context = NULL; /* Associate no context with this buffer */
-
    b->xm_visual = v;
    b->pbuffer_flag = GL_TRUE;
    b->display = v->display;
@@ -2022,6 +1997,7 @@ void XMesaDestroyBuffer( XMesaBuffer b )
 
    if (b->gc)  XMesaFreeGC( b->xm_visual->display, b->gc );
    if (b->cleargc)  XMesaFreeGC( b->xm_visual->display, b->cleargc );
+   if (b->swapgc)  XMesaFreeGC( b->xm_visual->display, b->swapgc );
 
    if (b->backimage) {
 #if defined(USE_XSHM) && !defined(XFree86Server)
@@ -2048,9 +2024,6 @@ void XMesaDestroyBuffer( XMesaBuffer b )
       XMesaDestroyImage( b->rowimage );
    }
 
-   if (b->xm_context)
-      b->xm_context->xm_buffer = NULL;
-
    free_xmesa_buffer(client, b);
 }
 
@@ -2079,17 +2052,6 @@ GLboolean XMesaMakeCurrent2( XMesaContext c, XMesaBuffer drawBuffer,
       if (drawBuffer->FXctx) {
          fxMesaMakeCurrent(drawBuffer->FXctx);
 
-         /* Disassociate drawBuffer's current context from drawBuffer */
-         if (drawBuffer->xm_context)
-            drawBuffer->xm_context->xm_buffer = NULL;
-
-         /* Disassociate old buffer from this context */
-         if (c->xm_buffer)
-            c->xm_buffer->xm_context = NULL;
-
-         /* Associate the context with this buffer */
-         drawBuffer->xm_context = c;
-
          c->xm_buffer = drawBuffer;
          c->xm_read_buffer = readBuffer;
          c->use_read_buffer = (drawBuffer != readBuffer);
@@ -2105,16 +2067,6 @@ GLboolean XMesaMakeCurrent2( XMesaContext c, XMesaBuffer drawBuffer,
          return GL_TRUE;
       }
 
-      /* Disassociate drawBuffer's current context from drawBuffer */
-      if (drawBuffer->xm_context)
-         drawBuffer->xm_context->xm_buffer = NULL;
- 
-      /* Disassociate old buffer with this context */
-      if (c->xm_buffer)
-	  c->xm_buffer->xm_context = NULL;
-
-      drawBuffer->xm_context = c; /* Associate the context with this buffer */
-
       c->xm_buffer = drawBuffer;
       c->xm_read_buffer = readBuffer;
       c->use_read_buffer = (drawBuffer != readBuffer);
@@ -2279,12 +2231,13 @@ GLboolean XMesaSetFXmode( GLint mode )
  */
 static void FXgetImage( XMesaBuffer b )
 {
+   GET_CURRENT_CONTEXT(ctx);
    static unsigned short pixbuf[MAX_WIDTH];
    GLuint x, y;
    int xpos, ypos;
    XMesaWindow root;
    unsigned int bw, depth, width, height;
-   XMesaContext xmesa = (XMesaContext) b->xm_context->gl_ctx->DriverCtx;
+   XMesaContext xmesa = (XMesaContext) ctx->DriverCtx;
 
    assert(xmesa->xm_buffer->FXctx);
 
@@ -2376,7 +2329,7 @@ void XMesaSwapBuffers( XMesaBuffer b )
    /* If we're swapping the buffer associated with the current context
     * we have to flush any pending rendering commands first.
     */
-   if (b->xm_context && b->xm_context->gl_ctx == ctx)
+   if (ctx && ctx->DrawBuffer == &(b->mesa_buffer))
       _mesa_swapbuffers(ctx);
 
    if (b->db_state) {
@@ -2396,7 +2349,7 @@ void XMesaSwapBuffers( XMesaBuffer b )
 	 if (b->shm) {
             /*_glthread_LOCK_MUTEX(_xmesa_lock);*/
 	    XShmPutImage( b->xm_visual->display, b->frontbuffer,
-			  b->cleargc,
+			  b->swapgc,
 			  b->backimage, 0, 0,
 			  0, 0, b->width, b->height, False );
             /*_glthread_UNLOCK_MUTEX(_xmesa_lock);*/
@@ -2406,7 +2359,7 @@ void XMesaSwapBuffers( XMesaBuffer b )
          {
             /*_glthread_LOCK_MUTEX(_xmesa_lock);*/
             XMesaPutImage( b->xm_visual->display, b->frontbuffer,
-			   b->cleargc,
+			   b->swapgc,
 			   b->backimage, 0, 0,
 			   0, 0, b->width, b->height );
             /*_glthread_UNLOCK_MUTEX(_xmesa_lock);*/
@@ -2418,7 +2371,7 @@ void XMesaSwapBuffers( XMesaBuffer b )
 	 XMesaCopyArea( b->xm_visual->display,
 			b->backpixmap,   /* source drawable */
 			b->frontbuffer,  /* dest. drawable */
-			b->cleargc,
+			b->swapgc,
 			0, 0, b->width, b->height,  /* source region */
 			0, 0                 /* dest region */
 		      );
@@ -2442,7 +2395,7 @@ void XMesaCopySubBuffer( XMesaBuffer b, int x, int y, int width, int height )
    /* If we're swapping the buffer associated with the current context
     * we have to flush any pending rendering commands first.
     */
-   if (b->xm_context->gl_ctx == ctx)
+   if (ctx && ctx->DrawBuffer == &(b->mesa_buffer))
       _mesa_swapbuffers(ctx);
 
    if (b->db_state) {
@@ -2462,7 +2415,7 @@ void XMesaCopySubBuffer( XMesaBuffer b, int x, int y, int width, int height )
          if (b->shm) {
             /* XXX assuming width and height aren't too large! */
             XShmPutImage( b->xm_visual->display, b->frontbuffer,
-                          b->cleargc,
+                          b->swapgc,
                           b->backimage, x, yTop,
                           x, yTop, width, height, False );
             /* wait for finished event??? */
@@ -2472,7 +2425,7 @@ void XMesaCopySubBuffer( XMesaBuffer b, int x, int y, int width, int height )
          {
             /* XXX assuming width and height aren't too large! */
             XMesaPutImage( b->xm_visual->display, b->frontbuffer,
-			   b->cleargc,
+			   b->swapgc,
 			   b->backimage, x, yTop,
 			   x, yTop, width, height );
          }
@@ -2482,7 +2435,7 @@ void XMesaCopySubBuffer( XMesaBuffer b, int x, int y, int width, int height )
          XMesaCopyArea( b->xm_visual->display,
 			b->backpixmap,           /* source drawable */
 			b->frontbuffer,          /* dest. drawable */
-			b->cleargc,
+			b->swapgc,
 			x, yTop, width, height,  /* source region */
 			x, yTop                  /* dest region */
                       );
@@ -2596,7 +2549,7 @@ void XMesaGarbageCollect( void )
    XMesaBuffer b, next;
    for (b=XMesaBufferList; b; b=next) {
       next = b->Next;
-      if (!b->pixmap_flag) {
+      if (b->display && b->frontbuffer && !b->pixmap_flag) {
 #ifdef XFree86Server
 	 /* NOT_NEEDED */
 #else
@@ -2676,3 +2629,13 @@ unsigned long XMesaDitherColor( XMesaContext xmesa, GLint x, GLint y,
 }
 
 
+/*
+ * This is typically called when the window size changes and we need
+ * to reallocate the buffer's back/depth/stencil/accum buffers.
+ */
+void XMesaResizeBuffers( XMesaBuffer b )
+{
+   xmesa_resize_buffers( &(b->mesa_buffer) );
+
+}
+
