@@ -1,4 +1,4 @@
-/* $Id: assyntax.h,v 1.16 2000/10/23 00:16:28 gareth Exp $ */
+/* $Id: assyntax.h,v 1.16.2.4 2002/04/01 17:09:25 brianp Exp $ */
 
 #ifndef __ASSYNTAX_H__
 #define __ASSYNTAX_H__
@@ -69,6 +69,11 @@
 
 #if !(defined(NASM_ASSEMBLER) || defined(MASM_ASSEMBLER))
 
+/* Default to ATT_ASSEMBLER when SVR4 or SYSV are defined */
+#if (defined(SVR4) || defined(SYSV)) && !defined(GNU_ASSEMBLER)
+#define ATT_ASSEMBLER
+#endif
+
 #if !defined(ATT_ASSEMBLER) && !defined(GNU_ASSEMBLER) && !defined(ACK_ASSEMBLER)
 #define GNU_ASSEMBLER
 #endif
@@ -200,6 +205,11 @@
 #define _STX6		%st(6)
 #define _STX7		%st(7)
 #define ST(x)		CONCAT(_STX,x)
+#ifdef GNU_ASSEMBLER
+#define ST0		%st(0)
+#else
+#define ST0		%st
+#endif
 /* MMX Registers */
 #define MM0		%mm0
 #define MM1		%mm1
@@ -244,7 +254,7 @@
 #endif /* ACK_ASSEMBLER */
 
 
-#if defined(__QNX__) || defined(Lynx) || (defined(SYSV) || defined(SVR4)) && !defined(ACK_ASSEMBLER) || defined(__ELF__) || defined(__GNU__)
+#if defined(__QNX__) || defined(Lynx) || (defined(SYSV) || defined(SVR4)) && !defined(ACK_ASSEMBLER) || defined(__ELF__) || defined(__GNU__) || defined(__GNUC__) && !defined(DJGPP)
 #define GLNAME(a)	a
 #else
 #define GLNAME(a)	CONCAT(_,a)
@@ -858,6 +868,7 @@
 #if defined(NASM_ASSEMBLER)
 
 #define ST(n)		st ## n
+#define ST0		st0
 
 #define TBYTE_PTR	tword
 #define QWORD_PTR	qword
