@@ -1,4 +1,4 @@
-/* $Id: dd.h,v 1.62 2001/06/15 14:18:46 brianp Exp $ */
+/* $Id: dd.h,v 1.62.2.2 2002/03/16 00:50:12 brianp Exp $ */
 
 /*
  * Mesa 3-D graphics library
@@ -31,6 +31,8 @@
 
 /* THIS FILE ONLY INCLUDED BY mtypes.h !!!!! */
 
+#include "macros.h"
+
 struct gl_pixelstore_attrib;
 
 /* Mask bits sent to the driver Clear() function */
@@ -97,9 +99,18 @@ struct dd_function_table {
     *    GL_NONE - disable buffer write in device driver.
     */
 
-   void (*GetBufferSize)( GLcontext *ctx, GLuint *width, GLuint *height );
+   void (*GetBufferSize)( GLframebuffer *buffer,
+                          GLuint *width, GLuint *height );
    /*
-    * Returns the width and height of the current color buffer.
+    * Returns the width and height of the named buffer/window.
+    * Mesa uses this to determine when the driver's window size has changed.
+    */
+
+   void (*ResizeBuffers)( GLframebuffer *buffer );
+   /*
+    * Resize the driver's depth/stencil/accum/back buffers to match the
+    * size given in the GLframebuffer struct.  This is typically called
+    * when Mesa detects that a window size has changed.
     */
 
    void (*Finish)( GLcontext *ctx );
@@ -164,9 +175,6 @@ struct dd_function_table {
    /* This is called by glBitmap.  Works the same as DrawPixels, above.
     */
 
-   void (*ResizeBuffersMESA)( GLcontext *ctx );
-
-
    /***
     *** Texture image functions:
     ***/
@@ -470,14 +478,17 @@ struct dd_function_table {
    void (*BlendFuncSeparate)(GLcontext *ctx,
                              GLenum sfactorRGB, GLenum dfactorRGB,
                              GLenum sfactorA, GLenum dfactorA);
+   void (*BlendConstColor)(GLcontext *ctx, GLfloat red, GLfloat green,
+                           GLfloat blue, GLfloat alpha);
    void (*ClearColor)(GLcontext *ctx, const GLchan color[4]);
    void (*ClearDepth)(GLcontext *ctx, GLclampd d);
    void (*ClearIndex)(GLcontext *ctx, GLuint index);
    void (*ClearStencil)(GLcontext *ctx, GLint s);
+   void (*ClipPlane)(GLcontext *ctx, GLenum plane, const GLfloat *equation );
    void (*ColorMask)(GLcontext *ctx, GLboolean rmask, GLboolean gmask,
                      GLboolean bmask, GLboolean amask );
+   void (*ColorMaterial)(GLcontext *ctx, GLenum face, GLenum mode);
    void (*CullFace)(GLcontext *ctx, GLenum mode);
-   void (*ClipPlane)(GLcontext *ctx, GLenum plane, const GLfloat *equation );
    void (*FrontFace)(GLcontext *ctx, GLenum mode);
    void (*DepthFunc)(GLcontext *ctx, GLenum func);
    void (*DepthMask)(GLcontext *ctx, GLboolean flag);
@@ -634,7 +645,6 @@ struct dd_function_table {
    void (*UnlockArraysEXT)( GLcontext *ctx );
    /* Called by glLockArraysEXT() and glUnlockArraysEXT(), respectively.
     */
-
 };
 
 
