@@ -1,27 +1,30 @@
-/* $Id: enums.c,v 1.9 2000/06/27 21:42:13 brianp Exp $ */
+/* $Id: enums.c,v 1.20 2001/06/08 20:10:55 brianp Exp $ */
 
 /*
  * Mesa 3-D graphics library
- * Version:  3.3
- * 
- * Copyright (C) 1999-2000  Brian Paul   All Rights Reserved.
- * 
+ * Version:  3.5
+ *
+ * Copyright (C) 1999-2001  Brian Paul   All Rights Reserved.
+ *
  * Permission is hereby granted, free of charge, to any person obtaining a
  * copy of this software and associated documentation files (the "Software"),
  * to deal in the Software without restriction, including without limitation
  * the rights to use, copy, modify, merge, publish, distribute, sublicense,
  * and/or sell copies of the Software, and to permit persons to whom the
  * Software is furnished to do so, subject to the following conditions:
- * 
+ *
  * The above copyright notice and this permission notice shall be included
  * in all copies or substantial portions of the Software.
- * 
+ *
  * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
  * OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
  * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL
  * BRIAN PAUL BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN
  * AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
  * CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+ *
+ * Author:
+ *    Keith Whitwell <keithw@valinux.com>
  */
 
 
@@ -34,12 +37,12 @@
 #endif
 
 
-typedef struct { 
-   const char *c; 
-   int n; 
+typedef struct {
+   const char *c;
+   int n;
 } enum_elt;
 
-enum_elt all_enums[] = 
+enum_elt all_enums[] =
 {
    /* Boolean values */
    { "GL_FALSE", 0 },
@@ -828,8 +831,21 @@ enum_elt all_enums[] =
    { "GL_INTERPOLATE_EXT", 0x8575 },
    { "GL_CONSTANT_EXT", 0x8576 },
    { "GL_PRIMARY_COLOR_EXT", 0x8577 },
-   { "GL_PREVIOUS_EXT", 0x8578 }
+   { "GL_PREVIOUS_EXT", 0x8578 },
 
+   /* GL_ARB_texture_env_combine */
+   { "GL_SUBTRACT_ARB", 0x84E7 },
+
+   /* GL_EXT_texture_env_dot3 */
+   { "GL_DOT3_RGB_EXT", 0x8740 },
+   { "GL_DOT3_RGBA_EXT", 0x8741 },
+
+   /* GL_ARB_texture_env_dot3 */
+   { "GL_DOT3_RGB_EXT", 0x86ae },
+   { "GL_DOT3_RGBA_EXT", 0x86af },
+
+   /* GL_ARB_texture_border_clamp */
+   { "GL_CLAMP_TO_BORDER_ARB", 0x812D },
 };
 
 #define Elements(x) sizeof(x)/sizeof(*x)
@@ -839,7 +855,7 @@ typedef int (GLWINAPIV *cfunc)(const void *, const void *);
 static enum_elt **index1 = 0;
 static int sorted = 0;
 
-static int compar_name( const enum_elt *a, const enum_elt *b ) 
+static int compar_name( const enum_elt *a, const enum_elt *b )
 {
    return strcmp(a->c, b->c);
 }
@@ -847,7 +863,7 @@ static int compar_name( const enum_elt *a, const enum_elt *b )
 
 /* note the extra level of indirection
  */
-static int compar_nr( const enum_elt **a, const enum_elt **b ) 
+static int compar_nr( const enum_elt **a, const enum_elt **b )
 {
    return (*a)->n - (*b)->n;
 }
@@ -855,14 +871,17 @@ static int compar_nr( const enum_elt **a, const enum_elt **b )
 
 static void sort_enums( void )
 {
-   int i;
+   GLuint i;
    index1 = (enum_elt **)MALLOC( Elements(all_enums) * sizeof(enum_elt *) );
    sorted = 1;
 
-   qsort( all_enums, Elements(all_enums), sizeof(*all_enums), 
+   if (!index1)
+      return;  /* what else can we do? */
+
+   qsort( all_enums, Elements(all_enums), sizeof(*all_enums),
 	  (cfunc) compar_name );
 
-   for (i = 0 ; i < Elements(all_enums) ; i++) 
+   for (i = 0 ; i < Elements(all_enums) ; i++)
       index1[i] = &all_enums[i];
 
    qsort( index1, Elements(all_enums), sizeof(*index1), (cfunc) compar_nr );
@@ -870,56 +889,46 @@ static void sort_enums( void )
 
 
 
-int gl_lookup_enum_by_name( const char *symbol )
+int _mesa_lookup_enum_by_name( const char *symbol )
 {
    enum_elt tmp;
    enum_elt *e;
 
-   if (!sorted) 
+   if (!sorted)
       sort_enums();
 
-   if (!symbol) 
+   if (!symbol)
       return 0;
 
    tmp.c = symbol;
-   e = (enum_elt *)bsearch( &tmp, all_enums, Elements(all_enums), 
+   e = (enum_elt *)bsearch( &tmp, all_enums, Elements(all_enums),
 			    sizeof(*all_enums), (cfunc) compar_name );
 
    return e ? e->n : -1;
 }
 
 
-const char *gl_lookup_enum_by_nr( int nr )
+static char token_tmp[20];
+
+const char *_mesa_lookup_enum_by_nr( int nr )
 {
    enum_elt tmp, *e, **f;
 
-   if (!sorted) 
+   if (!sorted)
       sort_enums();
 
    tmp.n = nr;
    e = &tmp;
 
-   f = (enum_elt **)bsearch( &e, index1, Elements(all_enums), 
+   f = (enum_elt **)bsearch( &e, index1, Elements(all_enums),
 			     sizeof(*index1), (cfunc) compar_nr );
 
-   return f ? (*f)->c : "(unknown)";
+   if (f) {
+      return (*f)->c;
+   }
+   else {
+      /* this isn't re-entrant safe, no big deal here */
+      sprintf(token_tmp, "0x%x", nr);
+      return token_tmp;
+   }
 }
-
-
-#if 0
-int main()
-{
-   int i;
-   static const char *test[] = {
-      "GL_POLYGON",
-      "GL_TRUE",
-      "GL_BANANA",
-      "GL_REFLECTION_MAP_NV",
-   };
-
-   for (i = 0 ; i < Elements(test) ; i++) {
-      int d = gl_lookup_enum_by_name( test[i] );
-      printf("%s --> %d --> %s\n", test[i], d, gl_lookup_enum_by_nr( d ));
-   }       
-}
-#endif
