@@ -1,4 +1,4 @@
-/* $Id: mmath.c,v 1.9 2001/03/12 00:48:38 gareth Exp $ */
+/* $Id: mmath.c,v 1.11 2001/09/18 16:16:21 kschultz Exp $ */
 
 /*
  * Mesa 3-D graphics library
@@ -55,38 +55,36 @@ static void init_sqrt(void)
 {
 #ifdef FAST_MATH
    unsigned short i;
-   float f;
-   unsigned int *fi = (unsigned int *)&f;
-                                /* to access the bits of a float in  */
-                                /* C quickly we must misuse pointers */
+   fi_type fi;     /* to access the bits of a float in  C quickly  */
+                   /* we use a union defined in glheader.h         */
 
    for(i=0; i<= 0x7f; i++) {
-      *fi = 0;
+      fi.i = 0;
 
       /*
        * Build a float with the bit pattern i as mantissa
        * and an exponent of 0, stored as 127
        */
 
-      *fi = (i << 16) | (127 << 23);
-      f = sqrt(f);
+      fi.i = (i << 16) | (127 << 23);
+      fi.f = sqrt(fi.f);
 
       /*
        * Take the square root then strip the first 7 bits of
        * the mantissa into the table
        */
 
-      sqrttab[i] = (*fi & 0x7fffff) >> 16;
+      sqrttab[i] = (fi.i & 0x7fffff) >> 16;
 
       /*
        * Repeat the process, this time with an exponent of
        * 1, stored as 128
        */
 
-      *fi = 0;
-      *fi = (i << 16) | (128 << 23);
-      f = sqrt(f);
-      sqrttab[i+0x80] = (*fi & 0x7fffff) >> 16;
+      fi.i = 0;
+      fi.i = (i << 16) | (128 << 23);
+      fi.f = sqrt(fi.f);
+      sqrttab[i+0x80] = (fi.i & 0x7fffff) >> 16;
    }
 #else
    (void) sqrttab;  /* silence compiler warnings */
@@ -97,16 +95,17 @@ static void init_sqrt(void)
 float gl_sqrt( float x )
 {
 #ifdef FAST_MATH
-   unsigned int *num = (unsigned int *)&x;
+   fi_type num;
                                 /* to access the bits of a float in C
-                                 * we must misuse pointers */
+                                 * we use a union from glheader.h     */
 
    short e;                     /* the exponent */
    if (x == 0.0F) return 0.0F;  /* check for square root of 0 */
-   e = (*num >> 23) - 127;      /* get the exponent - on a SPARC the */
+   num.f = x;
+   e = (num.i >> 23) - 127;     /* get the exponent - on a SPARC the */
                                 /* exponent is stored with 127 added */
-   *num &= 0x7fffff;            /* leave only the mantissa */
-   if (e & 0x01) *num |= 0x800000;
+   num.i &= 0x7fffff;           /* leave only the mantissa */
+   if (e & 0x01) num.i |= 0x800000;
                                 /* the exponent is odd so we have to */
                                 /* look it up in the second half of  */
                                 /* the lookup table, so we set the   */
@@ -118,10 +117,10 @@ float gl_sqrt( float x )
    /* Do the table lookup, based on the quaternary mantissa,
     * then reconstruct the result back into a float
     */
-   *num = ((sqrttab[*num >> 16]) << 16) | ((e + 127) << 23);
-   return x;
+   num.i = ((sqrttab[num.i >> 16]) << 16) | ((e + 127) << 23);
+   return num.f;
 #else
-   return sqrt(x);
+   return (GLfloat) sqrt(x);
 #endif
 }
 
@@ -141,7 +140,7 @@ _mesa_init_math(void)
    if (!initialized) {
       int i;
       for (i = 0; i < 256; i++) {
-         _mesa_ubyte_to_float_color_tab[i] = (float) i / 255.0;
+         _mesa_ubyte_to_float_color_tab[i] = (float) i / 255.0F;
       }
 
       init_sqrt();
