@@ -1,4 +1,4 @@
-/* $Id: mtypes.h,v 1.51.2.1 2001/11/06 15:51:07 brianp Exp $ */
+/* $Id: mtypes.h,v 1.51.2.3 2002/03/16 00:50:12 brianp Exp $ */
 
 /*
  * Mesa 3-D graphics library
@@ -1126,7 +1126,7 @@ struct gl_shared_state {
 struct gl_frame_buffer {
    GLvisual Visual;		/* The corresponding visual */
 
-   GLint Width, Height;		/* size of frame buffer in pixels */
+   GLuint Width, Height;	/* size of frame buffer in pixels */
 
    GLboolean UseSoftwareDepthBuffer;
    GLboolean UseSoftwareAccumBuffer;
@@ -1389,6 +1389,7 @@ struct gl_extensions {
 #define NEED_EYE_LIGHT           0x2
 #define NEED_EYE_LIGHT_MODELVIEW 0x4
 #define NEED_EYE_POINT_ATTEN     0x8
+#define NEED_EYE_DRIVER          0x10
 
 
 /*
