@@ -1,4 +1,4 @@
-/* $Id: t_imm_exec.c,v 1.29.2.1 2001/11/30 15:42:32 alanh Exp $ */
+/* $Id: t_imm_exec.c,v 1.29.2.3 2002/02/13 23:52:48 keithw Exp $ */
 
 /*
  * Mesa 3-D graphics library
@@ -136,7 +136,7 @@ void _tnl_copy_to_current( GLcontext *ctx, struct immediate *IM,
       COPY_4FV(ctx->Current.Color, IM->Color[count]);
       if (ctx->Light.ColorMaterialEnabled) {
 	 _mesa_update_color_material( ctx, ctx->Current.Color );
-	 _mesa_validate_all_lighting_tables( ctx );
+	 TNL_CONTEXT(ctx)->Driver.NotifyMaterialChange( ctx );
       }
    }
 
@@ -160,7 +160,7 @@ void _tnl_copy_to_current( GLcontext *ctx, struct immediate *IM,
 			  IM->Material[IM->LastMaterial],
 			  IM->MaterialOrMask );
 
-      _mesa_validate_all_lighting_tables( ctx );
+      TNL_CONTEXT(ctx)->Driver.NotifyMaterialChange( ctx );
    }
 }
 
@@ -343,7 +343,7 @@ static void _tnl_vb_bind_immediate( GLcontext *ctx, struct immediate *IM )
       }
    }
 
-   if ((inputs & VERT_MATERIAL) && IM->Material) {
+   if ((inputs & IM->OrFlag & VERT_MATERIAL) && IM->Material) {
       VB->MaterialMask = IM->MaterialMask + start;
       VB->Material = IM->Material + start;
    }
